@@ -36,10 +36,12 @@
 #include <IOKit/IOCommandGate.h>
 #include <IOKit/IOWorkLoop.h>
 #include <IOKit/IOSyncer.h>
-#include <IOKit/scsi-commands/SCSICmds_INQUIRY_Definitions.h>
+#include <IOKit/IORegistryEntry.h>
+#include <IOKit/scsi/SCSICmds_INQUIRY_Definitions.h>
 #include <IOKit/storage/IOStorageDeviceCharacteristics.h>
 
 
+#include "IOSCSIDevice.h"
 #include "IOSCSIParallelInterfaceProtocolTransport.h"
 
 
@@ -78,6 +80,12 @@ enum
 	kSCSICommandPoolSize	= 1
 };
 
+enum
+{
+	kMaxSenseDataSize		= 255
+};
+
+
 #define super IOSCSIProtocolServices
 OSDefineMetaClassAndStructors ( IOSCSIParallelInterfaceProtocolTransport, IOSCSIProtocolServices );
 
@@ -85,57 +93,6 @@ OSDefineMetaClassAndStructors ( IOSCSIParallelInterfaceProtocolTransport, IOSCSI
 #pragma mark -
 #pragma mark Public Methods
 
-//--------------------------------------------------------------------------------------
-//	 probe	-	Probe for devices we want to match on. This is temporary until Carbon
-//				uses SCSITaskLib instead of IOSCSILib.
-//--------------------------------------------------------------------------------------
-
-
-IOService *
-IOSCSIParallelInterfaceProtocolTransport::probe ( IOService * provider, SInt32 * score )
-{
-	
-	IOSCSIDevice *		scsiDevice;
-	OSNumber *			number;
-	UInt8				deviceType = 0xFF;
-	
-	if ( !super::probe ( provider, score ) )
-		return NULL;
-	
-	scsiDevice = OSDynamicCast ( IOSCSIDevice, provider );
-	if ( scsiDevice == NULL )
-		return NULL;
-	
-	number = ( OSNumber * ) provider->getProperty ( kSCSIPropertyDeviceTypeID );
-	if ( number != NULL )
-	{
-		
-		deviceType = number->unsigned8BitValue ( ) & kINQUIRY_PERIPHERAL_TYPE_Mask;
-		switch ( deviceType )
-		{
-			
-			case 0x00:	// Block
-			case 0x01:	// Sequential
-			case 0x05:	// MMC
-			case 0x07:	// MagnetoOptical
-			case 0x08:	// MediumChanger
-			case 0x0E:	// RBC
-				*score = 10000;
-				return this;
-				break;
-				
-			default:
-				break;
-			
-		}
-		
-	}
-	
-	return NULL;
-	
-}
-
-
 //--------------------------------------------------------------------------------------
 //	 start	-	Start our services
 //--------------------------------------------------------------------------------------
@@ -395,7 +352,7 @@ IOSCSIParallelInterfaceProtocolTransport::SendSCSICommand (
 	STATUS_LOG ( ( "Setting the auto-sense pointers\n" ) );
 	// Set the auto request-sense buffer for the command
 	cmd->setPointers ( 	clientData->senseBuffer,
-						sizeof ( SCSISenseData ),
+						clientData->senseBuffer->getLength ( ),
 						false,
 						true );
 	
@@ -467,7 +424,9 @@ IOSCSIParallelInterfaceProtocolTransport::SCSICallbackFunction (
 				
 				// Pull out the sense bytes here
 				ERROR_LOG ( ( "Pulling out sense data\n" ) );
-				SetAutoSenseData ( clientData->scsiTask, ( SCSI_Sense_Data * ) &clientData->senseBytes );
+				SetAutoSenseData ( clientData->scsiTask,
+								   ( SCSI_Sense_Data * ) clientData->senseBuffer->getBytesNoCopy ( ),
+								   clientData->senseBuffer->getLength ( ) );
 				ERROR_LOG ( ( "Finished setting sense data\n" ) );
 				
 			}
@@ -513,7 +472,9 @@ IOSCSIParallelInterfaceProtocolTransport::SCSICallbackFunction (
 					
 					// Pull out the sense bytes here
 					ERROR_LOG ( ( "Pulling out sense data\n" ) );
-					SetAutoSenseData ( clientData->scsiTask, ( SCSI_Sense_Data * ) &clientData->senseBytes );
+					SetAutoSenseData ( clientData->scsiTask,
+									   ( SCSI_Sense_Data * ) clientData->senseBuffer->getBytesNoCopy ( ),
+									   clientData->senseBuffer->getLength ( ) );
 					ERROR_LOG ( ( "Finished setting sense data\n" ) );
 					
 				}
@@ -713,6 +674,7 @@ IOSCSIParallelInterfaceProtocolTransport::InspectDevice ( IOSCSIDevice * scsiDev
 	
 	OSObject *		obj		= NULL;
 	OSDictionary *	dict	= NULL;
+	bool			created	= false;
 	
 	obj = getProperty ( kIOPropertyProtocolCharacteristicsKey, gIOServicePlane );
 	if ( obj != NULL )
@@ -736,6 +698,56 @@ IOSCSIParallelInterfaceProtocolTransport::InspectDevice ( IOSCSIDevice * scsiDev
 		
 	}
 	
+	obj = getProperty ( kIOPropertyProtocolCharacteristicsKey );
+	if ( obj == NULL )
+	{
+		
+		dict = OSDictionary::withCapacity ( 3 );
+		created = true;
+		
+	}
+	
+	else
+	{
+		dict = OSDynamicCast ( OSDictionary, obj );
+	}
+	
+	if ( dict != NULL )
+	{
+		
+		OSNumber *	domainID	= NULL;
+		OSNumber *	targetID 	= NULL;
+		OSNumber *	LUN		 	= NULL;
+		
+		domainID = OSDynamicCast ( OSNumber, scsiDevice->getProperty ( kIOPropertySCSIDomainIdentifierKey, gIOServicePlane ) );
+		if ( domainID != NULL )
+		{
+			dict->setObject ( kIOPropertySCSIDomainIdentifierKey, domainID );
+		}
+		
+		targetID = OSDynamicCast ( OSNumber, scsiDevice->getProperty ( kSCSIPropertyTarget ) );
+		if ( targetID != NULL )
+		{
+			dict->setObject ( kIOPropertySCSITargetIdentifierKey, targetID );
+		}
+		
+		LUN = OSDynamicCast ( OSNumber, scsiDevice->getProperty ( kSCSIPropertyLun ) );
+		if ( LUN != NULL )
+		{
+			dict->setObject ( kIOPropertySCSILogicalUnitNumberKey, LUN );
+		}
+		
+	}
+	
+	if ( created == true )
+	{
+		
+		setProperty ( kIOPropertyProtocolCharacteristicsKey, dict );
+		dict->release ( );
+		created = false;
+		
+	}
+	
 	return true;
 	
 }
@@ -764,9 +776,9 @@ IOSCSIParallelInterfaceProtocolTransport::AllocateSCSICommandObjects ( void )
 		clientData = ( SCSIClientData * ) cmd->getClientData ( );
 		assert ( clientData != NULL );
 		
-		clientData->senseBuffer = IOMemoryDescriptor::withAddress ( &clientData->senseBytes,
-																	sizeof ( SCSISenseData ),
-																	kIODirectionIn );
+		clientData->senseBuffer = IOBufferMemoryDescriptor::withCapacity ( kMaxSenseDataSize,
+																		   kIODirectionIn,
+																		   true );
 		
 		STATUS_LOG ( ( "adding command to pool\n" ) );
 		
